//R.C. Sachdeva, Fundamentals of Engineering Heat and Mass Transfer (SI Units),Fourth Edition, New Age International Publishers, 2010

//Chapter-8: Natural Convection
//Example: 8.10 Page 351
//Title: Heat transfer coefficient of wire
//======================================================

model Ex8_10
extends Modelica.Math;
import SI = Modelica.SIunits;

//=============
// Parameter Section

parameter Real D (unit = " m ") = 2.5e-3 " Outside diameter of wire ";
parameter Real T[2]( unit = " C ")= {25,95} " Temperatures of air and surface respectively";

//Surface properties at 100 degree celsius

parameter Real k (unit = " W/m C ") = 28.96e-3 " Thermal Conductivity of air ";
parameter Real v1 (unit = " m^2/s ") = 18.97e-6 " Kinematic Viscosity of air ";
parameter Real Pr( unit = "") =0.696 " Prandtl Number ";
parameter Real R( unit = " ohm/m") =6 " Resistance of the wire ";

final constant Real sigma(final unit="W/(m2.K4)") = 5.670367e-8 "Stefan-Boltzmann constant ";
final constant Real pi=2*Modelica.Math.asin(1.0); // 3.14159265358979;
final constant SI.Acceleration g_n=9.80665 "Standard acceleration of gravity on earth";

//=============
// Variable Section

Real B (unit = " K^-1 ") " Volumetric Coefficient of air ";
Real Tf(unit = " C") " Film Temperature ";
Real Ra( unit = "") " Rayleigh Number ";
Real Nu( unit = "") " Nusselt Number ";
Real h(unit = " W/m^2 C") " Average heat transfer coefficient";
Real Q(unit = " W/m") " Heat Loss per metre length ";
Real I(unit = " A") " Current flowing through the pipe ";

//=============
// Equation Section

equation

Tf=(T[1]+T[2])/2;
B=1/(Tf+273);
Ra= ((g_n*B*(D^3)*(T[2]-T[1])*Pr))/(v1^2);
Nu=1.18*(Ra^(1/8));
h=Nu*k/D;
Q=(h*pi*D*(T[2]-T[1]));
I=(Q/R)^0.5;

end Ex8_10;
//======================================================
